# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "1.1.2"
FULL_VERSION = "1.1.2.1.1.2"

ARCHIVES_BASE_NAME = "hextrapats"
CCA_VERSION = "5.2.3"
FABRIC_API_VERSION = "0.92.7+1.20.1"
FABRIC_KOTLIN_VERSION = "1.13.4+kotlin.2.2.0"
HEXCASTING_VERSION = "0.11.3"
LOADER_VERSION = "0.18.4"
LOOM_VERSION = "1.15-SNAPSHOT"
MAVEN_GROUP = "com.meepoffaith.hextrapats"
MINECRAFT_VERSION = "1.20.1"
MOD_VERSION = "1.1.2"
ORG_GRADLE_CONFIGURATION_CACHE = "false"
ORG_GRADLE_JVMARGS = "-Xmx1G"
ORG_GRADLE_PARALLEL = "true"
PKPCPBP_VER = "0.2.0-pre-95"
YARN_MAPPINGS = "1.20.1+build.10"
